# Copyright (C) 2011, Aleksey Lim
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Common defines."""

from gettext import gettext as _

from libmace import util


#: Path to the root directory with configuration templates.
source = util.Option(
        _('path to the root directory with configuration templates'),
        default='/etc/mace', short_option='-s')

#: Path to the root directory with configuration templates.
output = util.Option(
        _('path to the root directory with configuration templates'),
        default='/', short_option='-o')

#: LSB distributor id for targeted GNU/Linux distribution,
#: auto-detect by default.
distributor_id = util.Option(
        _('LSB distributor id for targeted GNU/Linux distribution, ' \
                'auto-detect by default'),
        short_option='-d')

#: LSB release number for targeted GNU/Linux distribution,
#: 'auto-detect by default.
release = util.Option(
        _('LSB release number for targeted GNU/Linux distribution, ' \
                'auto-detect by default'),
        short_option='-r')

#: Do not ask providers to apply configuration, just write configuration files.
dry_services = util.Option(
        _('do not ask providers to apply configuration, just write ' \
                'configuration files'),
        default=False, type_cast=bool, short_option='-S', action='store_true')

#: Colon separated list of providers to only enable.
include = util.Option(
        _('colon separated list of providers to only enable'),
        short_option='-I',
        type_cast=util.Option.list_cast, type_repr=util.Option.list_repr)

#: Colon separated list of providers to disable.
exclude = util.Option(
        _('colon separated list of providers to disable'),
        short_option='-X',
        type_cast=util.Option.list_cast, type_repr=util.Option.list_repr)

#: Colon separated list of keywords to include configs for.
keywords = util.Option(
        _('colon separated list of keywords to include configs for'),
        default='production', short_option='-K',
        type_cast=util.Option.list_cast, type_repr=util.Option.list_repr)

#: Force to rewrite configuration and reapply it.
force = util.Option(
        _('force to rewrite configuration and reapply it'),
        default=False, type_cast=bool, short_option='-f', action='store_true')

#: Debug logging level; multiple argument.
debug = util.Option(
        _('debug logging level; multiple argument'),
        default=0, type_cast=int, short_option='-D', action='count')

util.Option.seek('main')
