# Copyright (C) 2011, Aleksey Lim
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
Files and directories
---------------------

Configure arbitrary files and directories.

This provider uses artificial Mace-level configuration syntax in ini-files
format. Each ini section name is a path to configure.

List of supported options:
    :text:
        if specified, file will be processed and directory otherwise
    :mode:
        file mode; default mode if ommited
    :user:
        owner name or uid; root if ommited
    :group:
        owner group or gid; root if ommited

Mace configuration:
    :Service:
        ``files.d``
    :Confiles:
        No
    :Variables:
        No

Final configuration for all distributions:
    :Replaces:
        Yes
    :Files:
        No

"""
from gettext import gettext as _

from libmace.providers import BaseProvider
from libmace.util import enforce


class Provider(BaseProvider):

    @property
    def comment(self):
        return None

    @property
    def name(self):
        return 'files'

    @property
    def service_name(self):
        return None

    @property
    def files(self):
        return [None]

    def confile(self, filename):
        return None

    def apply(self, tran):
        for path in tran.config.sections():
            mode = tran.config[path, 'mode']
            if mode:
                enforce(mode.isdigit, _('File mode should be a digit in ' \
                        'configuration files for files.d provider'))
                mode = eval(mode)
            owner = (tran.config[path, 'user'] or 'root',
                     tran.config[path, 'group'] or 'root')
            content = tran.config[path, 'text']
            if content:
                tran.ensure_file(path, content=content, owner=owner, mode=mode)
            else:
                tran.ensure_dir(path, owner=owner, mode=mode)

        return not tran.empty
