# Copyright (C) 2011, Aleksey Lim
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
IPTables
--------

All configuration content should be in ``iptables-save`` format.
But ``COMMIT`` directive **should not** be used, it will be added automatically
by Mace.

Mace configuration:
    :Service:
        ``iptables.d``
    :Confiles:
        - ``filter`` for filter table rules
        - ``nat`` for nat table rules
        - ``mangle`` for mangle table rules
    :Variables:
        No

Fedora final configuration:
    :Replaces:
        Yes
    :Files:
        ``/etc/sysconfig/iptables``

"""
from libmace.providers import BaseProvider


class Provider(BaseProvider):

    @property
    def comment(self):
        return '#'

    @property
    def name(self):
        return 'iptables'

    @property
    def service_name(self):
        return 'iptables'

    @property
    def files(self):
        return ['filter', 'nat', 'mangle']

    def confile(self, filename):
        return '/etc/sysconfig/iptables'

    def confile_header(self, filename, conftext):
        return ['*%s' % filename]

    def confile_footer(self, filename, conftext):
        return ['COMMIT']
